@@ -2,7 +2,7 @@
 #
 """
 """
-# Copyright (C) 2012, GC3, University of Zurich. All rights reserved.
+# Copyright (C) 2012-2014, GC3, University of Zurich. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -22,6 +22,7 @@ __docformat__ = 'reStructuredText'
 __version__ = '$Revision$'
 
 
+import hashlib
 import os
 import re
 import paramiko
@@ -38,6 +39,7 @@ except ImportError:
         " was found. Please, install `boto` with `pip install boto`"
         " or `easy_install boto` and try again, or update your"
         " configuration file.")
+import Crypto
 
 # GC3Pie imports
 import gc3libs
@@ -45,7 +47,7 @@ from gc3libs.exceptions import RecoverableError, UnrecoverableError, \
     ConfigurationError, LRMSSkipSubmissionToNextIteration, UnrecoverableAuthError
 import gc3libs.url
 from gc3libs import Run
-from gc3libs.utils import same_docstring_as
+from gc3libs.utils import same_docstring_as, insert_char_every_n_chars
 from gc3libs.backends import LRMS
 from gc3libs.session import Session
 from gc3libs.persistence import Persistable
@@ -319,7 +321,6 @@ class EC2Lrms(LRMS):
         if self._conn is not None:
             return
 
-
         args = {'aws_access_key_id': self.ec2_access_key,
                 'aws_secret_access_key': self.ec2_secret_key,
                 }
@@ -413,6 +414,9 @@ class EC2Lrms(LRMS):
                     self.public_key)
             try:
                 pkey = paramiko.DSSKey.from_private_key_file(keyfile)
+                # AWS does not allow DSA keys, so no point in
+                # computing the alternate digest
+                key_for_aws_digest = None
             except paramiko.PasswordRequiredException:
                 raise RuntimeError(
                     "Key %s is encripted with a password. Please, use"
@@ -423,6 +427,9 @@ class EC2Lrms(LRMS):
                                   " %s", keyfile, ex)
                 try:
                     pkey = paramiko.RSAKey.from_private_key_file(keyfile)
+                    # we need PyCrypto for computing the alternate AWS digest
+                    with open(keyfile, 'r') as keydata:
+                        key_for_aws_digest = Crypto.PublicKey.RSA.importKey(keydata)
                 except paramiko.PasswordRequiredException:
                     raise RuntimeError(
                         "Key %s is encripted with a password. Please, use"
@@ -435,9 +442,22 @@ class EC2Lrms(LRMS):
                                      "RSA key nor a DSS key" % self.public_key)
 
             # Check key fingerprint
-            localkey_fingerprint = str.join(
-                ':', (i.encode('hex') for i in pkey.get_fingerprint()))
-            if localkey_fingerprint != keypairs[self.keypair_name].fingerprint:
+            localkey_fingerprints = [
+                # Usual SSH key fingerprint, computed like `ssh-keygen -l -f`
+                # This is used, e.g., by OpenStack's EC2 compatibility layer.
+                str.join(':', (i.encode('hex') for i in pkey.get_fingerprint())),
+            ]
+            if key_for_aws_digest:
+                localkey_fingerprints.append(
+                    # Amazon EC2 computes the key fingerprint in a
+                    # different way, see http://blog.jbrowne.com/?p=23 and
+                    # https://gist.github.com/jtriley/7270594 for details.
+                    insert_char_every_n_chars(
+                        hashlib.md5(key_for_aws_digest
+                                    .publickey()
+                                    .exportKey('DER')).hexdigest(), ':', 2),
+                )
+            if keypairs[self.keypair_name].fingerprint not in localkey_fingerprints:
                 gc3libs.log.error(
                     "Keypair `%s` is present but has different fingerprint: "
                     "%s != %s. Aborting!" % (
@@ -456,8 +476,7 @@ class EC2Lrms(LRMS):
             self._setup_security_groups()
             args['security_groups'] = [self.security_group_name]
 
-        # FIXME: we should add check/creation of proper security
-        # groups
+        # FIXME: we should add check/creation of proper security groups
         gc3libs.log.debug("Create new VM using image id `%s`", image_id)
         try:
             reservation = self._conn.run_instances(image_id, **args)
