@@ -8,7 +8,7 @@ function or class belongs in here is the following: place a function
 or class in this module if you could copy its code into the
 sources of a different project and it would not stop working.
 """
-# Copyright (C) 2009-2013 GC3, University of Zurich. All rights reserved.
+# Copyright (C) 2009-2014 GC3, University of Zurich. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -25,7 +25,7 @@ sources of a different project and it would not stop working.
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 #
 __docformat__ = 'reStructuredText'
-__version__ = '2.1.4 version (SVN $Revision: 3953 $)'
+__version__ = '2.1.5 version (SVN $Revision: 3967 $)'
 
 
 import itertools
@@ -388,9 +388,9 @@ class Enum(frozenset):
 
     Finally, enumeration labels can also be iterated upon::
 
-      >>> for a in Animal: print a
-      DOG
+      >>> for a in sorted(Animal): print a
       CAT
+      DOG
     """
     def __new__(cls, *args):
         return frozenset.__new__(cls, args)
@@ -535,6 +535,12 @@ def ifelse(test, if_true, if_false):
         return if_false
 
 
+# original source: https://gist.github.com/jtriley/7270594
+def insert_char_every_n_chars(string, char='\n', every=64):
+    return char.join(
+        string[i:i + every] for i in xrange(0, len(string), every))
+
+
 def irange(start, stop, step=1):
     """
     Iterate over all values greater or equal than `start` and less than `stop`.
@@ -1394,11 +1400,11 @@ def update_parameter_in_file(path, var_in, new_val, regex_in):
     '''
     Updates a parameter value in a parameter file using predefined regular
     expressions in `_loop_regexps`.
-    
-    :param path: Full path to the parameter file. 
-    :param var_in: The variable to modify. 
-    :param new_val: The updated parameter value. 
-    :param regex: Name of the regular expression that describes the format of the parameter file. 
+
+    :param path: Full path to the parameter file.
+    :param var_in: The variable to modify.
+    :param new_val: The updated parameter value.
+    :param regex: Name of the regular expression that describes the format of the parameter file.
     '''
     _loop_regexps = {
         'bar-separated':(r'([a-z]+[\s\|]+)'
